==> fusenshi-0.7.5.tgz: fusenshi-0.7.5/src/fio/xmlloader.cpp <==
/*
 * $Id: xmlloader.cpp,v 1.2 2004/11/05 08:08:30 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.2 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include "xmlloader.h"

/**
 * 󥹥ȥ饯
 */
XMLLoader::XMLLoader()
{
}

/**
 * ǥȥ饯
 */
XMLLoader::~XMLLoader()
{
}

/**
 * XMLեɤ߹ߤޤ
 * 
 * @param szFile ե̾
 * @return XMLɥ
 */
xmlDocPtr XMLLoader::load(Glib::ustring szFile)
{
    return xmlParseFile(szFile.c_str());
}

/**
 * XML꤫ɤ߹ߤޤ
 * 
 * @param buffer XMLʸ
 * @return XMLɥ
 */
xmlDocPtr XMLLoader::load(const GString* buffer)
{
    if (!buffer) return NULL;
    
    return xmlParseMemory(buffer->str, buffer->len);
}

==> fusenshi-0.8.2.tgz: fusenshi-0.8.2/src/fio/xmlloader.cpp <==
/*
 * $Id: xmlloader.cpp,v 1.3 2005/11/24 14:21:03 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.3 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include "xmlloader.h"

/**
 * 󥹥ȥ饯
 */
XMLLoader::XMLLoader()
{
}

/**
 * ǥȥ饯
 */
XMLLoader::~XMLLoader()
{
}

/**
 * XMLեɤ߹ߤޤ
 * 
 * @param szFile ե̾
 * @return XMLɥ
 */
xmlDocPtr XMLLoader::load(Glib::ustring szFile)
{
    return xmlParseFile(szFile.c_str());
}

/**
 * XML꤫ɤ߹ߤޤ
 * 
 * @param buffer XMLʸ
 * @return XMLɥ
 */
xmlDocPtr XMLLoader::load(const char* buffer)
{
    if (!buffer) return NULL;
    
    return xmlParseMemory(buffer, strlen(buffer));
}
